
# <img src="EDBOLogo.png" width="190">

## **EDBO+**. Bayesian reaction optimization as a tool for chemical synthesis

WebApp: https://www.edbowebapp.com

**Reference:** Garrido Torres, Jose A.; Lau, Sii Hong; Anchuri, Pranay; Stevens, Jason M.; Tabora, Jose E.; Li, Jun; Borovika, Alina; Adams, Ryan P.; Doyle, Abigail G. "A Multi-Objective Active Learning Platform and Web App for Reaction Optimization".

**DOI:** 10.26434/chemrxiv-2022-cljcp 

**Links**:
[ChemRxiv](https://chemrxiv.org/engage/chemrxiv/article-details/62f6966269f3a5df46b5584b).


<br>

---

<br>

### Installation:

<br>

(1) Create anaconda environment:

```
conda create --name edbo_env python=3.8
```

(2) Activate conda environment:

```
conda activate edbo_env
```

(3) Install EDBO+ dependencies:

```
pip install -e .
```

<br>

---

<br>

#### **Note**: to run the notebook tutorials install JupyterLab

```
conda install jupyterlab
```
